summaryrefslogtreecommitdiffstats
path: root/kioslaves/mbox/mbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kioslaves/mbox/mbox.h')
-rw-r--r--kioslaves/mbox/mbox.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kioslaves/mbox/mbox.h b/kioslaves/mbox/mbox.h
index 6d207ab3..159c4213 100644
--- a/kioslaves/mbox/mbox.h
+++ b/kioslaves/mbox/mbox.h
@@ -28,11 +28,11 @@ class KURL;
* This class is the main class and implements all function
* which can be called through the user.
*/
-class MBoxProtocol : public KIO::SlaveBase
+class MBoxProtocol : public TDEIO::SlaveBase
{
public:
/**
* Constructor, for the parameters, See KIO::SlaveBase
*/
MBoxProtocol( const TQCString&, const TQCString& );
/**
@@ -28,11 +28,11 @@ class KURL;
public:
/**
- * Constructor, for the parameters, See KIO::SlaveBase
+ * Constructor, for the parameters, See TDEIO::SlaveBase
*/
MBoxProtocol( const TQCString&, const TQCString& );